Alpha Documentation

Skip to content

# Welcome to Alpha environment documention

Alpha is an ecosystem based on multiple frameworks and libraries for both frontend and backend.

## Backend: Alphaz

- Alphaz is a backend toolbox/framework based on a combination between Flask, SqlAlchemy and a multitude of other libraries.

  Note

  The overriding goal for Alphaz is to ease the backend development and easely link python backend to Angular frontend [Alphaa].

## Features

- API Routing parameters management upgrade
- Enhanced json files configuration

## Tech

Alphaz uses a number of open source projects to work properly:

- Flask - a micro web framework
- SqlAlchemy - a database toolkit
- Flask-SqlAlchemy - an extension for Flask that adds support for SQLAlchemy

## Project layout

- How to setup `Alpha`: Alpha

## Frontend: Alphaa

- Alphaa is a frontend toolbox/framework

  Note

  The overriding goal for Alphaa is to ease the frontend development and easely link Angular frontend to python backend [Alphaz].

  ## Features

- Enhanced services

- Master class

## Project layout

- How to setup `Alpha`: Alpha